@@ -22,6 +22,12 @@ x
 summary(x)
 
 ## ----noteworthy2---------------------------------------------------------
+x <- as_noteworthy(x, format = "vector", octaves = "tick", accidentals = "flat")
+x
+
+summary(x)
+
+## ----noteworthy3---------------------------------------------------------
 x <- "a2 r b2*2 ce_g cd#g HELLO_WORLD"
 is_note(x)
 is_chord(x)
