@@ -18,6 +18,9 @@ test_that("interval helpers return as expected", {
   expect_equal(scale_interval("e,", "b"), "P12")
   expect_equal(scale_interval("e,", "b", ignore_octave = TRUE), "P5")
   expect_equal(scale_interval("e'", "c#'''"), "M13")
+  expect_equal(scale_interval("c#", "e_"), "M2")
+  expect_equal(scale_interval("d_", "e_"), "M2")
+  expect_identical(scale_interval("a", "c'''"), NA_character_)
 
   expect_equal(tuning_intervals(), c(0, 5, 10, 15, 19, 24))
 })
