@@ -6,5 +6,6 @@ test_that("tunings and mappings work", {
   purrr::walk(x, ~expect_identical(.map_tuning(.x), standard))
   expect_identical(.map_tuning(tunings$id[5]), tunings$value[5])
   err <- "Invalid `tuning`."
-  purrr::walk(c("dropd", "dadgad", "A", " h"), ~expect_error(.map_tuning(.x), err))
+  purrr::walk(c("dropd", "dadgad", "A", " h"),
+              ~expect_error(.map_tuning(.x), err))
 })
